@@ -15,21 +15,33 @@ from payloop._clients import OpenAi as OpenAiPayloopClient
 
 class Anthropic(BaseProvider):
     def register(self, client):
-        return AnthropicPayloopClient(self.config).register(client)
+        if self.client is None:
+            self.client = AnthropicPayloopClient(self.config).register(client)
+
+        return self.parent
 
 
 class Google(BaseProvider):
     def register(self, client):
-        return GooglePayloopClient(self.config).register(client)
+        if self.client is None:
+            self.client = GooglePayloopClient(self.config).register(client)
+
+        return self.parent
 
 
 class LangChain(BaseProvider):
     def register(self, chatopenai=None, chatvertexai=None):
-        return LangChainPayloopClient(self.config).register(
-            chatopenai=chatopenai, chatvertexai=chatvertexai
-        )
+        if self.client is None:
+            self.client = LangChainPayloopClient(self.config).register(
+                chatopenai=chatopenai, chatvertexai=chatvertexai
+            )
+
+        return self.parent
 
 
 class OpenAi(BaseProvider):
     def register(self, client):
-        return OpenAiPayloopClient(self.config).register(client)
+        if self.client is None:
+            self.client = OpenAiPayloopClient(self.config).register(client)
+
+        return self.parent
